quantizationtools.QEventProxy
=============================

.. abjad-lineage:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy

.. autoclass:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.index
      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.offset
      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.q_event
      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__eq__
      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__getstate__
      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__ne__
      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__repr__
      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__setstate__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.index
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.q_event
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__setstate__
   :noindex:
